package org.jenkinsci.plugins.p4_client.workspace;

import hudson.model.Descriptor;
import hudson.util.FormValidation;
import hudson.util.ListBoxModel;

import java.util.logging.Logger;

import org.jenkinsci.plugins.p4_client.client.ConnectionFactory;

import com.perforce.p4java.client.IClient;
import com.perforce.p4java.server.IOptionsServer;

public abstract class WorkspaceDescriptor extends Descriptor<Workspace> {

	private static Logger logger = Logger.getLogger(WorkspaceDescriptor.class
			.getName());

	public WorkspaceDescriptor(Class<? extends Workspace> clazz) {
		super(clazz);
	}

	protected WorkspaceDescriptor() {
	}

	/**
	 * Magic Stapler method; provides list of Charset types.
	 */
	public ListBoxModel doFillCharsetItems() {
		ListBoxModel list = new ListBoxModel();
		try {
			IOptionsServer p4 = ConnectionFactory.getConnection();
			for (String set : p4.getKnownCharsets()) {
				list.add(set);
			}
		} catch (Exception e) {
		}
		if (list.isEmpty()) {
			list.add("none");
		}
		return list;
	}

	public FormValidation checkClientName(String value) {
		try {
			IOptionsServer p4 = ConnectionFactory.getConnection();
			if (p4 == null) {
				// refresh issue; sometimes not available
				return FormValidation.ok();
			}
			IClient client = p4.getClient(value);
			if (client != null) {
				return FormValidation.ok();
			}
			return FormValidation.warning("Unknown Client: " + value);
		} catch (Exception e) {
			logger.warning("checkClientName: " + e);
			return FormValidation.error("Perforce connection error.");
		}
	}
}
